// $Id: alsa_mixer.h,v 1.13 2003/03/11 19:40:42 gordon Exp $	
//
// Copyright (C) 2002 Gordon Fraser <gordon@debian.org>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// See the COPYING file for more details
//

#ifndef __alsa_mixer_h__
#define __alsa_mixer_h__


#include <alsa/asoundlib.h>
#include <string>

#include "mixer.h"
#include "exception.h"
#include "alsa_device.h"

#include <vector>

/* #define CARD_NUM 0 */
/* #define MIXER_NUM 0 */

/* #define MIXER_ELEM_TYPE_MASK            0xff */
/* #define MIXER_ELEM_CAPTURE_SWITCH       0x100 */
/* #define MIXER_ELEM_MUTE_SWITCH          0x200 */
/* #define MIXER_ELEM_CAPTURE_SUFFIX       0x400 */

using std::vector;


//----------------------------------------------------------------------
class AlsaMixer : public Mixer
{
 protected:
  static const char CARD_NUM  = 0;
  static const char MIXER_NUM = 0;
  static const unsigned MIXER_ELEM_TYPE_MASK      = 0xff;
  static const unsigned MIXER_ELEM_CAPTURE_SWITCH = 0x100;
  static const unsigned MIXER_ELEM_MUTE_SWITCH    = 0x200;
  static const unsigned MIXER_ELEM_CAPTURE_SUFFIX = 0x400;


  snd_mixer_t *mixer_handle_;
  snd_mixer_elem_t *mixer_elements_;
  bool changed_state_;

  typedef std::vector<AlsaDevice*> device_list;
  device_list devices_;

  void initMixer()
    throw(MixerDeviceException);
    
 public:
  AlsaMixer() 
    throw(MixerDeviceException);
  AlsaMixer(const string& name) 
    throw(MixerDeviceException);
  virtual ~AlsaMixer();

  virtual void muteChannel(unsigned)
    throw(InvalidChannelException);
  virtual void unMuteChannel(unsigned)
    throw(InvalidChannelException);
  
  virtual void setChannelLeft(unsigned, unsigned)
    throw(InvalidChannelException);
  virtual void setChannelRight(unsigned, unsigned)
    throw(InvalidChannelException);  
  virtual bool toggleChannelRecord(unsigned)
    throw(InvalidChannelException);
  
  virtual bool hasChanged();
  virtual void doUpdate();
  virtual void doUpdate(unsigned)
    throw(InvalidChannelException);

  virtual bool isMuted(unsigned) const
    throw(InvalidChannelException);
  virtual bool isMono(unsigned) const
    throw(InvalidChannelException);
  virtual bool isSupported(unsigned) const
    throw(InvalidChannelException);
  virtual bool isEnabled(unsigned) const
    throw(InvalidChannelException);
  virtual bool canCapture(unsigned) const
    throw(InvalidChannelException);
  virtual bool getCapture(unsigned) const
    throw(InvalidChannelException);

  virtual unsigned getChannelLeft(unsigned) const
    throw(InvalidChannelException);
  virtual unsigned getChannelRight(unsigned) const
    throw(InvalidChannelException);
  virtual const string& getChannelName(unsigned) const
    throw(InvalidChannelException);

  virtual void disableChannel(unsigned)
    throw(InvalidChannelException);
  virtual void enableChannel(unsigned)
    throw(InvalidChannelException);

};

/* static int mixer_changed_state = 1; */
/* static int alsaMixerEvent (snd_mixer_t *mixer, unsigned int mask, snd_mixer_elem_t *elem) */
/* {  */
/*   std::cout << "*** CALLBACK *** " << mask << snd_mixer_selem_get_name(elem) << std::endl; */
/*   mixer_changed_state = true; */
/*   return 0; */
/* } */


#endif //__alsa_mixer_h__
