// $Id: config_reader.cc,v 1.9 2003/03/11 17:09:37 gordon Exp $	
//
// Copyright (C) 2002 Gordon Fraser <gordon@debian.org>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// See the COPYING file for more details
//

#include "config_reader.h"

//-------------------------------------------------------------------
ConfigReader::ConfigReader(const string& filename)
  : file_name_(filename)
{
  std::ifstream file_(filename.c_str()); // = std::ifstream(filename);
  if(!file_)
  {
    throw FileNotFoundException(filename);
  }
  scanner_ = yyFlexLexer(&file_);
  yyparse();
  //    config_file_.dumpSections();
}

//-------------------------------------------------------------------
ConfigReader::~ConfigReader()
{
  //   delete file_;
}

//-------------------------------------------------------------------
const string& ConfigReader::getFileName() const
{
  return file_name_;
}

//-------------------------------------------------------------------
int ConfigReader::yylex()
{
  return scanner_.yylex(&yylval);
}

//-------------------------------------------------------------------
void ConfigReader::yyerror(char* message)
{
  std::cerr << "Lexer error: " << message << std::endl;
  
  std::cerr << yylloc.first_line << ": " << message
     	    << " at token '" << yylloc.text << "'" << std::endl;
}

//-------------------------------------------------------------------
const char* ConfigReader::getStringParameter(const char* section, const char* parameter) const
{
  return config_file_.getStringParameter(section, parameter);
}

//-------------------------------------------------------------------
int ConfigReader::getIntParameter(const char* section, const char* parameter) const
{
  return config_file_.getIntParameter(section, parameter);
}



//--------------------------------------------------------------------
list<int>& ConfigReader::getIntListParameter(const char* section, const char* parameter) const
{
  // FIXXME - ugly

  const char* in_char = getStringParameter(section, parameter);
  list<int>* ls = new list<int>;
  if(in_char == 0)
  {
    return *ls;
  }
  string in(in_char);
  const char* const delimiters = ",";

  const string::size_type len = in.length();
  string::size_type i = 0;
  
    
  while ( i < len )
  {
    // eat leading whitespace
    i = in.find_first_not_of (delimiters, i);
    if (i == string::npos)
      return *ls;   // nothing left but white space
	
    // find the end of the token
    string::size_type j = in.find_first_of (delimiters, i);
	
    // push token
    if (j == string::npos) 
    {
      ls->push_back (atoi((in.substr(i)).c_str()));
      return *ls;
    } 
    else
      ls->push_back (atoi((in.substr(i, j-i)).c_str()));
	
    // set up for next loop
    i = j + 1;
  }
  return *ls;
}


//====================================================================
// int main(int argc, char** argv)
// {
//   ConfigReader aCompiler;
//   int result=aCompiler.yyparse();
//   printf("Result Parsing=%s\n",result?"Error":"OK");
//   return 0;  
// }
