// $Id: device.cc,v 1.8 2003/03/11 17:09:37 gordon Exp $	
//
// Copyright (C) 2002 Gordon Fraser <gordon@debian.org>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// See the COPYING file for more details
//

#include "device.h"

//----------------------------------------------------------------------
Device::Device(bool is_supported, bool is_stereo, bool is_recordable,
	       bool record_source, const string& device_name)
  : is_recordable_(is_recordable), is_supported_(is_supported),
    is_stereo_(is_stereo), is_enabled_(true), is_muted_(false),
    record_source_(record_source), left_value_(0), right_value_(0),
    left_muted_(0), right_muted_(0), name_(device_name)
{
}

//----------------------------------------------------------------------
Device::~Device()
{
}

//----------------------------------------------------------------------
void Device::mute()
{
  left_muted_  = left_value_;
  right_muted_ = right_value_;
  left_value_  = 0;
  right_value_ = 0;
  is_muted_    = true;
}

//----------------------------------------------------------------------
void Device::unMute()
{
  left_value_  = left_muted_;
  right_value_ = right_muted_;
  left_muted_  = 0;
  right_muted_ = 0;
  is_muted_    = false;
}

//----------------------------------------------------------------------
unsigned Device::getLeftValue() const
{
  return left_value_;
}

//----------------------------------------------------------------------
unsigned Device::getRightValue() const
{
  return right_value_;
}

//----------------------------------------------------------------------
void Device::setLeftValue(unsigned value)
{
  left_value_ = value;
}

//----------------------------------------------------------------------
void Device::setRightValue(unsigned value)
{
  right_value_ = value;
}

//----------------------------------------------------------------------
const string& Device::getLabel() const
{
  return name_;
}

//----------------------------------------------------------------------
void Device::enable()
{
  is_enabled_ = true;
}

//----------------------------------------------------------------------
void Device::disable()
{
  is_enabled_ = false;
}
