// $Id: graphics.cc,v 1.9 2003/02/09 19:28:00 gordon Exp $	
//
// Copyright (C) 2002 Gordon Fraser <gordon@debian.org>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// See the COPYING file for more details
//

#include "graphics.h"

//--------------------------------------------------------------------
Graphics::Graphics(int argc, char** argv,
		   const string& display, const string& position, char x_flags)
{
  x_handler_ = new XHandler(display, position, x_flags);
  x_handler_->init(argc, argv);
}

//--------------------------------------------------------------------
Graphics::~Graphics()
{
  delete x_handler_;
}

//--------------------------------------------------------------------
XHandler* Graphics::getXHandler()
{
  return x_handler_;
}

//--------------------------------------------------------------------
Display* Graphics::getDisplay()
{
  return x_handler_->getDisplay();
}

//--------------------------------------------------------------------
Window Graphics::getWindow()
{
  return x_handler_->getWindow();
}

//--------------------------------------------------------------------
void Graphics::drawImage(Image* image, unsigned x, unsigned y,
			 unsigned width, unsigned height)
{
  x_handler_->drawPixmap(image->getPixmap(), x, y, width, height);
}

//--------------------------------------------------------------------
void Graphics::drawImageOffset(Image* image, unsigned startx, 
			       unsigned starty, unsigned x, unsigned y,
			       unsigned width, unsigned height)
{
  x_handler_->drawPixmapOffset(image->getPixmap(), startx, starty,
			       x, y, width, height);
}

//--------------------------------------------------------------------
void Graphics::drawText(const char* text, FontMap* font, unsigned x,
			unsigned y, unsigned width, unsigned height)
{
  char* helper;
  unsigned pos;
  int char_pos;

  for(helper = (char*)text, pos = x; 
      *helper!='\0'; 
      helper++, pos += font->getWidth())
  {
    if(pos > width)
      return;

    char_pos = font->getX(*helper);

    if(char_pos < 0)
      continue;

    x_handler_->drawPixmapOffset(font->getPixmap(), 
				 char_pos, 0,  
				 pos, y, font->getWidth(), height);
  }
}

//--------------------------------------------------------------------
void Graphics::drawButton(Image* image, unsigned x, unsigned y, 
			  unsigned width, unsigned height, bool state)
{
  if(!state)
    x_handler_->drawPixmap(image->getPixmap(), x, y, width, height);
  else
    x_handler_->drawShade(image->getPixmap(), x, y, width, height);
}

//--------------------------------------------------------------------
void Graphics::drawRectangle(Color* color, unsigned x, unsigned y,
			     unsigned width, unsigned height)
{
  x_handler_->drawRectangle(color->getColor(), x, y, width, height);
}

//--------------------------------------------------------------------
void Graphics::redraw()
{
  x_handler_->redraw();
}
